dev@glassfish.java.net

Re: How do I change what ends up in the "modules" dir?

From: Ed Burns <edward.burns_at_oracle.com>
Date: Thu, 8 Sep 2011 18:50:51 -0700

>>>>> On Thu, 8 Sep 2011 15:01:44 -0700 (PDT), Snjezana Sevo-Zenzerovic <snjezana.sevozenzerovic_at_oracle.com> said:

SSZ> So, you updated packager/glassfish-jsf/pom.xml dependencies to
SSZ> include new jar, correct?

[...]

SSZ> dependency. You can send me resulting tree.log file and I'll take a
SSZ> look.

Once we discovered the fighterfish link, your timely suggestion saved
the day.

Please find attached the changebundle.

I would really like a close review from Snjezana, Jane, and Shing-Wai.

As I said, I did run quicklook and the admingui on this, and those both
ran well, but even so, I want to make sure I didn't miss anything. I
did go over the diff very carefully and found a few thing while doing
so, such as a missing closing % in the windows batch file, and a missing
. in the Class-Path but it stands to reason that if I missed such things
twice, I way have missed them more than twice.

Ed

-- 
| edward.burns_at_oracle.com | office: +1 407 458 0017
| homepage:               | http://ridingthecrest.com/
| 12 business days until JSF 2.2 Early Draft Review
| 16 business days until JavaOne 2011


Subject: pom.xml and default-web.xml review request: integrate JSF 2.1.3

This change-bundle integrates JSF 2.1.3. I have run the quicklook tests
with these jars pulled fresh from maven to a local repo and the tests
ran successfully to completion.

I have also brought up the adminGUI web application (as this exercises
on the new JSF version). It worked just fine.

Note that this changebundle is the first to use the single jar package
for Mojarra.

SECTION: Modified Files

M deployment/dol/src/test/java/com/sun/enterprise/deployment/OrderingDescriptorTest.java

- Replace jsf-ri with javax.faces.jar in comments

M core/kernel/src/test/resources/DomainTest.xml
M jdbc/admin/src/test/resources/DomainTest.xml
M common/common-util/src/test/resources/v2domain.xml

- replace jsf-impl.jar with javax.faces.jar in <jvm-options>

M pom.xml

- Remove jsf-api.version and jsf-impl.version properties. Replace with
  mojarra.version property

M javaee-api/javax.javaee/src/main/assembly/web-api-assembly.xml
M javaee-api/javax.javaee/src/main/assembly/api-assembly.xml

- <include>com.sun.faces:jsf-api</include>
- <include>com.sun.faces:jsf-impl</include>
+ <include>org.glassfish:javax.faces</include>

M javaee-api/javax.javaee/pom.xml
M tests/embedded/maven-plugin/jsftest/pom.xml
M tests/embedded/web/web-war/test/pom.xml
M packager/glassfish-jsf/pom.xml
M web/jsf-connector/pom.xml
M web/weld-integration/pom.xml
M admingui/common/pom.xml
M admingui/pom.xml

- replace jsf-api and jsf-impl dependencies with a single javax.faces
  dependency.

M javadoc.xml

- replace jsf-api dependency with javax.faces-api

M extras/javaee/manifest-jar/src/main/resources/META-INF/MANIFEST.MF

- Modify Class-Path to replace jsf-api.jar with javax.faces.jar.

M packager/nucleus-base/lib/templates/default-web.xml

- replace jsf-api.jar and jsf-impl.jar with javax.faces.jar

M packager/nucleus-base/bin/jspc
M packager/nucleus-base/bin/jspc.bat

- remove JSF_API variable

- make JSF_IMPL variable's value be javax.faces.jar

M packager/pom.xml

- Snjezana Sevo-Zenzerovic's ever so helpful tip got me past this
  troublesome maven transitive dependency blockage regarding
  fighterfish.

M packager/glassfish-jsf/src/main/resources/pkg_proto.py

- Change URL, replace dev.java.net with java.net

M packager/resources/pkg_conf.py

- 2.1.3 is final.

M web/web-glue/src/main/java/com/sun/enterprise/web/WebModuleListener.java

- remove reference to jsf-impl.jar and jsf-api.jar

- add reference to javax.faces.jar

M web/jsf-connector/src/main/resources/META-INF/services/org.glassfish.faces.integration.GlassFishInjectionProvider

- In comment, change reference to jsf-impl.jar to be a reference to
  javax.faces.jar


SECTION: Diffs

Index: deployment/dol/src/test/java/com/sun/enterprise/deployment/OrderingDescriptorTest.java
===================================================================
--- deployment/dol/src/test/java/com/sun/enterprise/deployment/OrderingDescriptorTest.java (revision 49371)
+++ deployment/dol/src/test/java/com/sun/enterprise/deployment/OrderingDescriptorTest.java (working copy)
@@ -60,7 +60,7 @@
 
 /**
  * This class tests relative order sorting.
- * The first part of tests are ported from jsf-ri TestFacesConfigOrdering.java.
+ * The first part of tests are ported from javax.faces.jar TestFacesConfigOrdering.java.
  *
  * @author Shing Wai Chan
  */
@@ -129,7 +129,7 @@
         wfs.add(createWebFragmentDescriptor("E", null, new String[] { OTHERS }));
         wfs.add(createWebFragmentDescriptor("F", null, null));
         OrderingDescriptor.sort(wfs);
- //an alternative result from jsf-ri
+ //an alternative result from javax.faces.jar
         //String[] ids = { "B", "E", "F", "", "C", "D" };
         String[] ids = { "E", "B", "F", "D", "", "C" };
         validate(ids, wfs);
@@ -145,7 +145,7 @@
         wfs.add(createWebFragmentDescriptor("E", new String[] { "C" }, new String[] { OTHERS }));
         wfs.add(createWebFragmentDescriptor("F", null, null));
         OrderingDescriptor.sort(wfs);
- //an alternative result from jsf-ri
+ //an alternative result from javax.faces.jar
         //String[] ids = { "B", "C", "E", "F", "A", "D" };
         String[] ids = { "C", "E", "B", "F", "D", "A" };
         validate(ids, wfs);
@@ -159,7 +159,7 @@
         wfs.add(createWebFragmentDescriptor("C", null, new String[] { OTHERS }));
         wfs.add(createWebFragmentDescriptor("D", null, null));
         OrderingDescriptor.sort(wfs);
- //an alternative result from jsf-ri
+ //an alternative result from javax.faces.jar
         //String[] ids = { "C", "B", "D", "A" };
         String[] ids = { "C", "D", "B", "A" };
         validate(ids, wfs);
@@ -221,7 +221,7 @@
         wfs.add(createWebFragmentDescriptor("C", null, new String[] { "B" }));
         wfs.add(createWebFragmentDescriptor("D", null, null));
         OrderingDescriptor.sort(wfs);
- //an alternative result from jsf-ri
+ //an alternative result from javax.faces.jar
         //String[] ids = { "A", "C", "D", "B" };
         String[] ids = { "C", "B", "A", "D" };
         validate(ids, wfs);
Index: core/kernel/src/test/resources/DomainTest.xml
===================================================================
--- core/kernel/src/test/resources/DomainTest.xml (revision 49371)
+++ core/kernel/src/test/resources/DomainTest.xml (working copy)
@@ -181,8 +181,8 @@
         <jvm-options>-Djava.ext.dirs=${com.sun.aas.javaRoot}/lib/ext${path.separator}${com.sun.aas.javaRoot}/jre/lib/ext${path.separator}${com.sun.aas.instanceRoot}/lib/ext${path.separator}${com.sun.aas.derbyRoot}/lib</jvm-options>
         <jvm-options>-Djdbc.drivers=org.apache.derby.jdbc.ClientDriver</jvm-options>
         <jvm-options>-Dcom.sun.enterprise.config.config_environment_factory_class=com.sun.enterprise.config.serverbeans.AppserverConfigEnvironmentFactory</jvm-options>
- <jvm-options>-Dcom.sun.enterprise.taglibs=appserv-jstl.jar,jsf-impl.jar</jvm-options>
- <jvm-options>-Dcom.sun.enterprise.taglisteners=jsf-impl.jar</jvm-options>
+ <jvm-options>-Dcom.sun.enterprise.taglibs=appserv-jstl.jar,javax.faces.jar</jvm-options>
+ <jvm-options>-Dcom.sun.enterprise.taglisteners=javax.faces.jar</jvm-options>
         <jvm-options>-XX:NewRatio=2</jvm-options>
       </java-config>
       <thread-pools>
Index: pom.xml
===================================================================
--- pom.xml (revision 49371)
+++ pom.xml (working copy)
@@ -104,8 +104,7 @@
         <el-impl.version>2.2.1-b03</el-impl.version>
         <jstl-impl.version>1.2</jstl-impl.version>
         <jstl-api.version>1.2</jstl-api.version>
- <jsf-api.version>2.1.3-b02</jsf-api.version>
- <jsf-impl.version>2.1.3-b02</jsf-impl.version>
+ <mojarra.version>2.1.3</mojarra.version>
         <jsf-ext.version>0.2</jsf-ext.version>
         <woodstock.version>4.0.2.8</woodstock.version>
         <grizzly.version>1.9.36</grizzly.version>
@@ -904,9 +903,9 @@
             </dependency>
 
             <dependency>
- <groupId>com.sun.faces</groupId>
- <artifactId>jsf-api</artifactId>
- <version>${jsf-api.version}</version>
+ <groupId>org.glassfish</groupId>
+ <artifactId>javax.faces</artifactId>
+ <version>${mojarra.version}</version>
             </dependency>
 
             <dependency>
@@ -1117,11 +1116,6 @@
                 <version>${weld.version}</version>
             </dependency>
             <dependency>
- <groupId>com.sun.faces</groupId>
- <artifactId>jsf-impl</artifactId>
- <version>${jsf-impl.version}</version>
- </dependency>
- <dependency>
                 <groupId>org.osgi</groupId>
                 <artifactId>org.osgi.compendium</artifactId>
                 <version>4.2.0</version>
Index: jdbc/admin/src/test/resources/DomainTest.xml
===================================================================
--- jdbc/admin/src/test/resources/DomainTest.xml (revision 49371)
+++ jdbc/admin/src/test/resources/DomainTest.xml (working copy)
@@ -181,8 +181,8 @@
         <jvm-options>-Djava.ext.dirs=${com.sun.aas.javaRoot}/lib/ext${path.separator}${com.sun.aas.javaRoot}/jre/lib/ext${path.separator}${com.sun.aas.instanceRoot}/lib/ext${path.separator}${com.sun.aas.derbyRoot}/lib</jvm-options>
         <jvm-options>-Djdbc.drivers=org.apache.derby.jdbc.ClientDriver</jvm-options>
         <jvm-options>-Dcom.sun.enterprise.config.config_environment_factory_class=com.sun.enterprise.config.serverbeans.AppserverConfigEnvironmentFactory</jvm-options>
- <jvm-options>-Dcom.sun.enterprise.taglibs=appserv-jstl.jar,jsf-impl.jar</jvm-options>
- <jvm-options>-Dcom.sun.enterprise.taglisteners=jsf-impl.jar</jvm-options>
+ <jvm-options>-Dcom.sun.enterprise.taglibs=appserv-jstl.jar,javax.faces.jar</jvm-options>
+ <jvm-options>-Dcom.sun.enterprise.taglisteners=javax.faces.jar</jvm-options>
         <jvm-options>-XX:NewRatio=2</jvm-options>
       </java-config>
       <thread-pools>
Index: javaee-api/javax.javaee/src/main/assembly/web-api-assembly.xml
===================================================================
--- javaee-api/javax.javaee/src/main/assembly/web-api-assembly.xml (revision 49371)
+++ javaee-api/javax.javaee/src/main/assembly/web-api-assembly.xml (working copy)
@@ -94,8 +94,7 @@
                 <include>org.glassfish:javax.xml.rpc</include>
                 <include>org.glassfish:javax.activation</include>
                 <include>javax.xml.bind:jaxb-api-osgi</include>
- <include>com.sun.faces:jsf-api</include>
- <include>com.sun.faces:jsf-impl</include>
+ <include>org.glassfish:javax.faces</include>
                 <include>org.glassfish:javax.servlet.jsp</include>
                 <include>org.glassfish:javax.jws</include>
                 <include>javax.ws.rs:jsr311-api</include>
Index: javaee-api/javax.javaee/src/main/assembly/api-assembly.xml
===================================================================
--- javaee-api/javax.javaee/src/main/assembly/api-assembly.xml (revision 49371)
+++ javaee-api/javax.javaee/src/main/assembly/api-assembly.xml (working copy)
@@ -96,8 +96,7 @@
                 <include>org.glassfish:javax.activation</include>
                 <include>javax.xml.bind:jaxb-api-osgi</include>
                 <include>org.glassfish:javax.xml.bind</include>
- <include>com.sun.faces:jsf-api</include>
- <include>com.sun.faces:jsf-impl</include>
+ <include>org.glassfish:javax.faces</include>
                 <include>org.glassfish:javax.servlet.jsp</include>
                 <include>org.glassfish:javax.jws</include>
                 <include>javax.ws.rs:jsr311-api</include>
Index: javaee-api/javax.javaee/pom.xml
===================================================================
--- javaee-api/javax.javaee/pom.xml (revision 49371)
+++ javaee-api/javax.javaee/pom.xml (working copy)
@@ -226,16 +226,12 @@
             <artifactId>jaxb-api-osgi</artifactId>
         </dependency>
         <dependency>
- <groupId>com.sun.faces</groupId>
- <artifactId>jsf-api</artifactId>
+ <groupId>org.glassfish</groupId>
+ <artifactId>javax.faces</artifactId>
+ <version>${mojarra.version}</version>
             <optional>true</optional>
         </dependency>
         <dependency>
- <groupId>com.sun.faces</groupId>
- <artifactId>jsf-impl</artifactId>
- <optional>true</optional>
- </dependency>
- <dependency>
             <groupId>org.glassfish</groupId>
             <artifactId>javax.servlet.jsp</artifactId>
             <version>${project.version}</version>
Index: tests/embedded/maven-plugin/jsftest/pom.xml
===================================================================
--- tests/embedded/maven-plugin/jsftest/pom.xml (revision 49371)
+++ tests/embedded/maven-plugin/jsftest/pom.xml (working copy)
@@ -155,9 +155,9 @@
             <scope>provided</scope>
         </dependency>
         <dependency>
- <groupId>com.sun.faces</groupId>
- <artifactId>jsf-api</artifactId>
- <version>2.1.0</version>
+ <groupId>org.glassfish</groupId>
+ <artifactId>javax.faces</artifactId>
+ <version>${mojarra.version}</version>
             <scope>provided</scope>
         </dependency>
 <!--
Index: tests/embedded/web/web-war/test/pom.xml
===================================================================
--- tests/embedded/web/web-war/test/pom.xml (revision 49371)
+++ tests/embedded/web/web-war/test/pom.xml (working copy)
@@ -176,16 +176,9 @@
         </dependency>
 
         <dependency>
- <groupId>com.sun.faces</groupId>
- <artifactId>jsf-impl</artifactId>
- <version>${jsf-impl.version}</version>
- <scope>test</scope>
+ <groupId>org.glassfish</groupId>
+ <artifactId>javax.faces</artifactId>
+ <version>${mojarra.version}</version>
         </dependency>
- <dependency>
- <groupId>com.sun.faces</groupId>
- <artifactId>jsf-api</artifactId>
- <version>${jsf-api.version}</version>
- <scope>test</scope>
- </dependency>
    </dependencies>
 </project>
Index: javadoc.xml
===================================================================
--- javadoc.xml (revision 49371)
+++ javadoc.xml (working copy)
@@ -311,7 +311,7 @@
 
   <target name="jsf.download" description="Download JSF" depends="initialize.maven">
       <artifact:dependencies sourcesFilesetId="sources.dependency.jsf">
- <dependency groupId="com.sun.faces" artifactId="jsf-api" version="2.1.0-b11"/>
+ <dependency groupId="javax.faces" artifactId="javax.faces-api" version="2.1"/>
           <remoteRepository refid="nexus.repository" />
           <localRepository path="${maven.repo.local}"/>
       </artifact:dependencies>
Index: extras/javaee/manifest-jar/src/main/resources/META-INF/MANIFEST.MF
===================================================================
--- extras/javaee/manifest-jar/src/main/resources/META-INF/MANIFEST.MF (revision 49371)
+++ extras/javaee/manifest-jar/src/main/resources/META-INF/MANIFEST.MF (working copy)
@@ -2,5 +2,5 @@
 Archiver-Version: Plexus Archiver
 Created-By: Apache Maven
 Build-Jdk:
-Class-Path: ../modules/javax.servlet.jar ../modules/endorsed/javax.annotation.jar ../modules/javax.ejb.jar ../modules/javax.transaction.jar ../modules/javax.enterprise.deploy.jar ../modules/javax.management.j2ee.jar ../modules/javax.resource.jar ../modules/javax.security.auth.message.jar ../modules/javax.security.jacc.jar ../modules/webservices-osgi.jar ../modules/jaxb-osgi.jar ../modules/endorsed/jaxb-api-osgi.jar ../modules/endorsed/webservices-api-osgi.jar ../modules/javax.mail.jar ../modules/jsf-api.jar ../modules/javax.servlet.jsp.jar ../modules/javax.servlet.jsp.jstl.jar ../modules/javax.persistence.jar ../modules/javax.jms.jar ../modules/bean-validator.jar ../modules/weld-osgi-bundle.jar ../../mq/lib/jaxm-api.jar ../modules/jersey-core.jar
+Class-Path: ../modules/javax.servlet.jar ../modules/endorsed/javax.annotation.jar ../modules/javax.ejb.jar ../modules/javax.transaction.jar ../modules/javax.enterprise.deploy.jar ../modules/javax.management.j2ee.jar ../modules/javax.resource.jar ../modules/javax.security.auth.message.jar ../modules/javax.security.jacc.jar ../modules/webservices-osgi.jar ../modules/jaxb-osgi.jar ../modules/endorsed/jaxb-api-osgi.jar ../modules/endorsed/webservices-api-osgi.jar ../modules/javax.mail.jar ../modules/javax.faces.jar ../modules/javax.servlet.jsp.jar ../modules/javax.servlet.jsp.jstl.jar ../modules/javax.persistence.jar ../modules/javax.jms.jar ../modules/bean-validator.jar ../modules/weld-osgi-bundle.jar ../../mq/lib/jaxm-api.jar ../modules/jersey-core.jar
 GlassFish-ServerExcluded: true
Index: packager/nucleus-base/lib/templates/default-web.xml
===================================================================
--- packager/nucleus-base/lib/templates/default-web.xml (revision 49371)
+++ packager/nucleus-base/lib/templates/default-web.xml (working copy)
@@ -315,13 +315,12 @@
         \lib\
         jstl-impl.jar
         el-impl.jar
+ javax.faces.jar
         javax.servlet.jar
         javax.servlet.jsp.jar
         javax.servlet.jsp.jstl.jar
         javax.jms.jar
- jsf-api.jar
         jsp-impl.jar
- jsf-impl.jar
         jspcaching-connector.jar
         web-glue.jar
         bean-validator.jar
Index: packager/nucleus-base/bin/jspc
===================================================================
--- packager/nucleus-base/bin/jspc (revision 49371)
+++ packager/nucleus-base/bin/jspc (working copy)
@@ -48,9 +48,8 @@
 EL_IMPL=$AS_INSTALL_LIB/el-impl.jar
 JSTL_API=$AS_INSTALL_LIB/javax.servlet.jsp.jstl.jar
 JSTL_IMPL=$AS_INSTALL_LIB/jstl-impl.jar
-JSF_API=$AS_INSTALL_LIB/jsf-api.jar
-JSF_IMPL=$AS_INSTALL_LIB/jsf-impl.jar
+JSF_IMPL=$AS_INSTALL_LIB/javax.faces.jar
 AS_LIB=$AS_INSTALL/lib
 
-java -cp "$SERVLET_API:$JSP_API:$ANT_LIB:$JSTL_API:$JSF_API:$EL_IMPL:$JSP_IMPL:$AS_LIB" org.apache.jasper.JspC -sysClasspath "$SERVLET_API:$JSP_API:$JSP_IMPL:$JSTL_API:$JSTL_IMPL:$JSF_API:$JSF_IMPL:$ANT_LIB:$AS_LIB" -schemas "/schemas/" -dtds "/dtds/" "$@"
+java -cp "$SERVLET_API:$JSP_API:$ANT_LIB:$JSTL_API:$JSF_IMPL:$EL_IMPL:$JSP_IMPL:$AS_LIB" org.apache.jasper.JspC -sysClasspath "$SERVLET_API:$JSP_API:$JSP_IMPL:$JSTL_API:$JSTL_IMPL:$JSF_IMPL:$ANT_LIB:$AS_LIB" -schemas "/schemas/" -dtds "/dtds/" "$@"
 
Index: packager/nucleus-base/bin/jspc.bat
===================================================================
--- packager/nucleus-base/bin/jspc.bat (revision 49371)
+++ packager/nucleus-base/bin/jspc.bat (working copy)
@@ -48,8 +48,7 @@
 set EL_IMPL=%AS_INSTALL_LIB%\el-impl.jar
 set JSTL_API=%AS_INSTALL_LIB%\javax.servlet.jsp.jstl.jar
 set JSTL_IMPL=%AS_INSTALL_LIB%\jstl-impl.jar
-set JSF_API=%AS_INSTALL_LIB%\jsf-api.jar
-set JSF_IMPL=%AS_INSTALL_LIB%\jsf-impl.jar
+set JSF_IMPL=%AS_INSTALL_LIB%\javax.faces.jar
 set AS_LIB=%~dp0..\lib
 
-java -cp "%SERVLET_API%;%JSP_API%;%JSTL_API%;%JSF_API%;%ANT_LIB%;%EL_IMPL%;%JSP_IMPL%;%AS_LIB%" org.apache.jasper.JspC -sysClasspath "%SERVLET_API%;%JSP_API%;%JSP_IMPL%;%JSTL_API%;%JSTL_IMPL%;%JSF_API%;%JSF_IMPL%;%ANT_LIB%;%AS_LIB%" -schemas "/schemas/" -dtds "/dtds/" %*
+java -cp "%SERVLET_API%;%JSP_API%;%JSTL_API%;%JSF_IMPL;%ANT_LIB%;%EL_IMPL%;%JSP_IMPL%;%AS_LIB%" org.apache.jasper.JspC -sysClasspath "%SERVLET_API%;%JSP_API%;%JSP_IMPL%;%JSTL_API%;%JSTL_IMPL%;%JSF_IMPL%;%ANT_LIB%;%AS_LIB%" -schemas "/schemas/" -dtds "/dtds/" %*
Index: packager/pom.xml
===================================================================
--- packager/pom.xml (revision 49371)
+++ packager/pom.xml (working copy)
@@ -75,7 +75,7 @@
     <properties>
         <install.dir.name>glassfish3</install.dir.name>
         <findbugs.skip>true</findbugs.skip>
- <packager.artifact.excludes>stax-api,stax,junit,jtype,tiger-types,servlet-api,jstl-api,el-api,jsp-api,org.osgi.core,org.osgi.compendium,concurrent,amx-core,amx-core-impl,amx-config,amx-config-impl,amx-j2ee,amx-j2ee-impl,amx-ext-impl,gmbal-api-only</packager.artifact.excludes>
+ <packager.artifact.excludes>stax-api,stax,junit,jtype,tiger-types,servlet-api,jstl-api,el-api,jsp-api,org.osgi.core,org.osgi.compendium,concurrent,amx-core,amx-core-impl,amx-config,amx-config-impl,amx-j2ee,amx-j2ee-impl,amx-ext-impl,gmbal-api-only,jsf-api,jsf-ri</packager.artifact.excludes>
     </properties>
 
     <modules>
Index: packager/glassfish-jsf/src/main/resources/pkg_proto.py
===================================================================
--- packager/glassfish-jsf/src/main/resources/pkg_proto.py (revision 49371)
+++ packager/glassfish-jsf/src/main/resources/pkg_proto.py (working copy)
@@ -49,7 +49,7 @@
     "version" : conf.jsf_version,
     "attributes" : {
                         "pkg.summary" : "GlassFish JSF",
- "pkg.description" : "GlassFish Java Server Faces Technology (JSF) module simplifies building user interfaces for JavaServer applications. Developers of various skill levels can quickly build web applications by: assembling reusable UI components in a page; connecting these components to an application data source; and wiring client-generated events to server-side event handlers. For more information, see https://javaserverfaces.dev.java.net/. "+conf.glassfish_description_long,
+ "pkg.description" : "GlassFish Java Server Faces Technology (JSF) module simplifies building user interfaces for JavaServer applications. Developers of various skill levels can quickly build web applications by: assembling reusable UI components in a page; connecting these components to an application data source; and wiring client-generated events to server-side event handlers. For more information, see https://javaserverfaces.java.net/. "+conf.glassfish_description_long,
                         "info.classification" : conf.glassfish_info_classification,
                       },
     "depends" : {
Index: packager/glassfish-jsf/pom.xml
===================================================================
--- packager/glassfish-jsf/pom.xml (revision 49371)
+++ packager/glassfish-jsf/pom.xml (working copy)
@@ -99,13 +99,10 @@
         -->
  
        <dependency>
- <groupId>com.sun.faces</groupId>
- <artifactId>jsf-api</artifactId>
+ <groupId>org.glassfish</groupId>
+ <artifactId>javax.faces</artifactId>
+ <version>${mojarra.version}</version>
        </dependency>
- <dependency>
- <groupId>com.sun.faces</groupId>
- <artifactId>jsf-impl</artifactId>
- </dependency>
 
             <!-- now, listing package dependencies so that their content
              can be excluded during staging -->
Index: packager/resources/pkg_conf.py
===================================================================
--- packager/resources/pkg_conf.py (revision 49371)
+++ packager/resources/pkg_conf.py (working copy)
@@ -64,7 +64,7 @@
 felix_version="3.0.8,0-0"
 javadb_version="10.5.3.0,0-0"
 corba_version="3.1.0,0-30"
-jsf_version="2.1.3,0-4"
+jsf_version="2.1.3,0-0"
 grizzly_version="1.9.36,0-1"
 metro_version="2.1.1,0-9"
 javahelp_version="2.0.2,0-1"
Index: web/jsf-connector/src/main/resources/META-INF/services/org.glassfish.faces.integration.GlassFishInjectionProvider
===================================================================
--- web/jsf-connector/src/main/resources/META-INF/services/org.glassfish.faces.integration.GlassFishInjectionProvider (revision 49371)
+++ web/jsf-connector/src/main/resources/META-INF/services/org.glassfish.faces.integration.GlassFishInjectionProvider (working copy)
@@ -1,5 +1,5 @@
 # Hack to make GlassFishInjectionProvider visible globally in GFv3,
-# so that jsf-impl.jar can discover it from webapp classloaders.
+# so that javax.faces.jar can discover it from webapp classloaders.
 #
 # When HK2 sees the service discovery pattern, it exposes the classes
 # to all the modules in the habitat (AKA class loader punch-in)
Index: web/jsf-connector/pom.xml
===================================================================
--- web/jsf-connector/pom.xml (revision 49371)
+++ web/jsf-connector/pom.xml (working copy)
@@ -86,16 +86,12 @@
             <version>${project.version}</version>
         </dependency>
         <dependency>
- <groupId>com.sun.faces</groupId>
+ <groupId>org.glassfish</groupId>
             <scope>provided</scope>
- <artifactId>jsf-api</artifactId>
+ <artifactId>javax.faces</artifactId>
+ <version>${mojarra.version}</version>
         </dependency>
         <dependency>
- <groupId>com.sun.faces</groupId>
- <scope>provided</scope>
- <artifactId>jsf-impl</artifactId>
- </dependency>
- <dependency>
             <groupId>org.glassfish.common</groupId>
             <artifactId>glassfish-api</artifactId>
             <version>${project.version}</version>
Index: web/weld-integration/pom.xml
===================================================================
--- web/weld-integration/pom.xml (revision 49371)
+++ web/weld-integration/pom.xml (working copy)
@@ -85,14 +85,11 @@
     </build>
     <dependencies>
         <dependency>
- <groupId>com.sun.faces</groupId>
- <artifactId>jsf-impl</artifactId>
+ <groupId>org.glassfish</groupId>
+ <artifactId>javax.faces</artifactId>
+ <version>${mojarra.version}</version>
         </dependency>
         <dependency>
- <groupId>com.sun.faces</groupId>
- <artifactId>jsf-api</artifactId>
- </dependency>
- <dependency>
             <groupId>org.glassfish.web</groupId>
             <artifactId>web-glue</artifactId>
             <version>${project.version}</version>
Index: common/common-util/src/test/resources/v2domain.xml
===================================================================
--- common/common-util/src/test/resources/v2domain.xml (revision 49371)
+++ common/common-util/src/test/resources/v2domain.xml (working copy)
@@ -223,8 +223,8 @@
         <jvm-options>-Djdbc.drivers=org.apache.derby.jdbc.ClientDriver</jvm-options>
         <jvm-options>-Djavax.management.builder.initial=com.sun.enterprise.admin.server.core.jmx.AppServerMBeanServerBuilder</jvm-options>
         <jvm-options>-Dcom.sun.enterprise.config.config_environment_factory_class=com.sun.enterprise.config.serverbeans.AppserverConfigEnvironmentFactory</jvm-options>
- <jvm-options>-Dcom.sun.enterprise.taglibs=appserv-jstl.jar,jsf-impl.jar</jvm-options>
- <jvm-options>-Dcom.sun.enterprise.taglisteners=jsf-impl.jar</jvm-options>
+ <jvm-options>-Dcom.sun.enterprise.taglibs=appserv-jstl.jar,javax.faces.jar</jvm-options>
+ <jvm-options>-Dcom.sun.enterprise.taglisteners=javax.faces.jar</jvm-options>
         <jvm-options>-XX:NewRatio=2</jvm-options>
         <!--
         Use the following jvm-options element to disable the quick startup:
Index: admingui/common/pom.xml
===================================================================
--- admingui/common/pom.xml (revision 49371)
+++ admingui/common/pom.xml (working copy)
@@ -149,8 +149,9 @@
             <version>${project.version}</version>
         </dependency>
         <dependency>
- <groupId>com.sun.faces</groupId>
- <artifactId>jsf-api</artifactId>
+ <groupId>org.glassfish</groupId>
+ <artifactId>javax.faces</artifactId>
+ <version>${mojarra.version}</version>
         </dependency>
         <dependency>
             <groupId>com.sun.jersey</groupId>
Index: admingui/pom.xml
===================================================================
--- admingui/pom.xml (revision 49371)
+++ admingui/pom.xml (working copy)
@@ -144,8 +144,9 @@
             <scope>provided</scope>
         </dependency>
         <dependency>
- <groupId>com.sun.faces</groupId>
- <artifactId>jsf-api</artifactId>
+ <groupId>org.glassfish</groupId>
+ <artifactId>javax.faces</artifactId>
+ <version>${mojarra.version}</version>
             <scope>provided</scope>
         </dependency>
         <dependency>
Index: web/web-glue/src/main/java/com/sun/enterprise/web/WebModuleListener.java
===================================================================
--- web/web-glue/src/main/java/com/sun/enterprise/web/WebModuleListener.java (revision 49371)
+++ web/web-glue/src/main/java/com/sun/enterprise/web/WebModuleListener.java (working copy)
@@ -268,17 +268,15 @@
             defaultHabitat,
             webModule.getID(), null
         );
// If the configuration flag usMyFaces is set, remove jsf-api.jar
// and jsf-impl.jar from the system class path
         Boolean useMyFaces = (Boolean)
             servletContext.getAttribute("com.sun.faces.useMyFaces");
         if (useMyFaces != null && useMyFaces) {
             sysClassPath =
- sysClassPath.replace("jsf-api.jar", "$disabled$.raj");
+ sysClassPath.replace("javax.faces.jar", "$disabled$.raj");
+ // jsf-connector.jar manifest has a Class-Path to javax.faces.jar
             sysClassPath =
- sysClassPath.replace("jsf-impl.jar", "$disabled$.raj");
- // jsf-connector.jar manifest has a Class-Path to jsf-impl.jar
- sysClassPath =
                 sysClassPath.replace("jsf-connector.jar", "$disabled$.raj");
         }
         // TODO: combine with classpath from
@@ -268,17 +268,15 @@
             webModule.getID(), null
         );
- // If the configuration flag usMyFaces is set, remove jsf-api.jar
- // and jsf-impl.jar from the system class path
+ // If the configuration flag usMyFaces is set, remove javax.faces.jar
+ // and from the system class path
         Boolean useMyFaces = (Boolean)
             servletContext.getAttribute("com.sun.faces.useMyFaces");